{% load articlecategory %}
{% if categories %}
<ul>
    {% for category in categories %} 
    <li>
        <a{{ category|equals:selected|then:" class='current'" }} href="{{ category.get_absolute_url }}">{{ category }}</a>
        {% articlecategories selected category %}
    </li>
{% endfor %}
</ul>
{% endif %}
