{% extends "articles/base.html" %}

{% load i18n feincms_tags %}

{% block article-title %}<h3>{{ object }}</h3>{% endblock %}

{% block article-aside %}{% endblock %}

{% block article-content %}
    <div class="article full">

        <div class="body">
            {% feincms_render_region object 'main' request %}
        </div>
    </div>
{% endblock %}
    
