{% extends "articles/base.html" %}

{% load feincms_tags i18n %}

{% block article-title %}
    <h2>{% trans 'Articles' %}</h2>
{% endblock %}

{% block article-content %}

    {% for article in object_list %}  
    <div class="article short">
        <div class="summary">
            <h3><a href="{{ article.get_absolute_url }}">{{ article }}</a></h3>
            {% feincms_render_region article 'summary' request %}
        </div>
    </div>
    {% endfor %}

{% endblock %}
